/*
 * This minimal sketch will load the ESP32 board Over the Air (OTA) from a build
 * in the Wevolor folder on hghst.net and then reboot.  If the LED comes on
 * the OTA has failed.
 *
 * Change the SSID and PASSWORD to your settings.
 *
 * wevolor_OTA - code by Roger Hoggarth (wevolor@hghst.net)
 * 
 */

#include <WiFi.h>
#include <ESP32httpUpdate.h>

String WEVOLOR_PATH = "/Wevolor/";

// ***************************************
// Change the following to your settings
//
#define WIFI_SSID "your-SSID"
#define WIFI_PASSWORD "your-password"
//
// ***************************************

// ************************************************************
// Change this if a different version is required
// Example: version 5.2 would be blind_BLE_5_2.ino.lolin32.bin
String WEVOLOR_CODE = "blinds_BLE_5_4_2.ino.lolin32.bin";

void setup() {
  Serial.begin(115200);

  pinMode(LED_BUILTIN, OUTPUT);     // initialize digital ledPin as an output.
  digitalWrite(LED_BUILTIN, HIGH);  // Active low, so HIGH is OFF
 
  delay(10);

  // We start by connecting to a WiFi network

  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(WIFI_SSID);

  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);
 
  while (WiFi.status() != WL_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  Serial.println("");
  Serial.println("WiFi connected.");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());

  delay(500);

  String file = WEVOLOR_PATH + WEVOLOR_CODE;
  Serial.print("Update beginning with file: "); Serial.println(file.c_str());

  if(ESPhttpUpdate.update("hghst.net", 80, file) != HTTP_UPDATE_OK) {
    Serial.println("Update Error - ESPhttpUpdate failed");     
  }

  // If the call to update is successful will not get here
  Serial.println("Update looks good - rebooting");
  digitalWrite(LED_BUILTIN, LOW);  // Active low, so LOW is On
}

void loop() {
  // put your main code here, to run repeatedly:
  delay(1000);
}
